/***************************************************************************
                          check_pocket.h  -  description
                             -------------------
    begin                : Tue Jan 8 2002
    copyright            : (C) 1999-2002 by Brian Ashe & Jacques Fortier
    email                : gtkpool@seul.org
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef CHECK_POCKET_H
#define CHECK_POCKET_H
#include "ball.h"
#include "game.h"


/**
  *@author Brian Ashe & Jacques Fortier
  */

class check_pocket {
public: 
	int left, right, top, bottom, left_of_mid, right_of_mid;
	double time;
	int ball_num, category;
	bool cue, eight, solid, stripe, nine;

	check_pocket(GdkRectangle table, double ei);
	~check_pocket();
	bool operator() (Ball &b);	
};

#endif
